#
# spec file for package libltc
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 11
Name:           libltc
Version:        1.1.4
Release:        3.2
Summary:        Linear/longitudinal timecode library
License:        LGPL-3.0+
Group:          Development/Libraries/C and C++
Url:            https://github.com/x42/libltc
Source0:        https://github.com/x42/libltc/releases/download/v%{version}/%{name}-%{version}.tar.gz
Patch0:         libltc_doxyfile_no_timestamp.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Linear (or Longitudinal) Timecode (LTC) is an encoding of SMPTE timecode
data as a Manchester-Biphase encoded audio signal. The audio signal is
commonly recorded on a VTR track or other storage media.

libltc provides functionality to encode and decode LTC audio from/to SMPTE
or EBU timecode, including SMPTE date support.

%package -n %{name}%{sover}
Summary:        Linear/longitudinal timecode library
Group:          System/Libraries

%description -n %{name}%{sover}
Linear (or Longitudinal) Timecode (LTC) is an encoding of SMPTE timecode
data as a Manchester-Biphase encoded audio signal. The audio signal is
commonly recorded on a VTR track or other storage media.

libltc provides functionality to encode and decode LTC audio from/to SMPTE
or EBU timecode, including SMPTE date support.

%package devel
Summary:        Linear/longitudinal timecode library
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel
Linear (or Longitudinal) Timecode (LTC) is an encoding of SMPTE timecode
data as a Manchester-Biphase encoded audio signal. The audio signal is
commonly recorded on a VTR track or other storage media.

libltc provides functionality to encode and decode LTC audio from/to SMPTE
or EBU timecode, including SMPTE date support.

%prep
%setup -q
%patch0 -p1

%build
%configure --disable-static
make %{?_smp_mflags} all dox

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
find %{buildroot} -type f -name '*.la' -delete -print
%fdupes -s doc/

%check
make %{?_smp_mflags} check

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog README.md
%{_libdir}/libltc.so.*

%files devel
%defattr(-,root,root)
%doc doc/html
%{_includedir}/ltc.h
%{_libdir}/libltc.so
%{_libdir}/pkgconfig/ltc.pc
%{_mandir}/man3/ltc.h.3.gz

%changelog
* Sun Feb 21 2016 jengelh@inai.de
- Avoid building static libs since they get removed anyway.
  Requires uses one equals sign.
* Fri Feb 12 2016 mpluskal@suse.com
- Do not ship static library
- Update dependencies/provides
  * add pkg-config
  * remove manual provides
- Cleanup spec file
* Sat Jun 14 2014 virtuousfox@gmail.com
- Update to 1.1.4
  2014-05-16 (v1.1.4) Robin Gareus <robin@gareus.org>
  * rework endianess detection
  * fix compile on systems w/o endian.h
  * remove obsolte autotools macros
* Tue Mar  4 2014 dnh@opensuse.org
- Initial build.
  Changes from previous versions:
  2013-11-09 (v1.1.3) Robin Gareus <robin@gareus.org>
  * fixes for the release & test scripts (by Nils Philippsen)
  * update links to releases in doc.
  2013-09-06 (v1.1.2) Robin Gareus <robin@gareus.org>
  * better BIG_ENDIAN detection (should fix mips, sparc, s390 builds)
  * fix decoder_write_u16() -- use unsigned short
  * allow to use buffersizes larger than 1024 samples with ltc_decoder_write_*
  2012-11-18 (v1.1.1) Robin Gareus <robin@gareus.org>
  * start LTC frame with rising edge
  * fix typo in variable name and clarify documentation
  2012-11-17 (v1.1.0) Robin Gareus <robin@gareus.org>
  * non-backwards compatible API update for 12M-1999 spec additions
- rework encoder and frame inc/dec API.
- add support for TV-standard offset and binary-group-flags
  * fix LTCFrame struct for big-endian architectures
  * fix volume db calculation
  * update default rise-time - 40us
  * fix timezone 0x0a -> -0030
  2012-11-09 (v1.0.3) Robin Gareus <robin@gareus.org>
  * fix version-number in header (was stuck at 1.0.1)
  * fix internal  buffer size of non-integer fps
  * add API call to reset encoder state
  * reset encoder-state when calling reinit()
  2012-11-06 (v1.0.2) Robin Gareus <robin@gareus.org>
  * fix man-page doxygen minus vs hyphen issue
  * allow to reset date parameters when assigning timecode|frame
  * improve decoder audio-sample position accuracy:
  take difference of current biphase count to nominal period
  duration into account.
  (thanks to Chris Goddard for OSC sample-sync measurements)
  2012-11-03 (v1.0.1) Robin Gareus <robin@gareus.org>
  * fix release tar-ball: remove cruft from test/
  * fix typo in README and update description
  * no code changes.
  2012-11-02 (v1.0.0) Robin Gareus <robin@gareus.org>
  * freeze interface defition - 1.0.0
  * update doc
  * minor tweaks and typos (OSX build,
  printf size_t warning, LPGL boilerplate)
  2012-10-25 (v0.8.1) Robin Gareus <robin@gareus.org>
  * add interface to decode 16bit and 32bit float data
  (wrappers around ltc_decoder_write() - internally 8 bit)
  2012-10-24 (v0.8.0) Robin Gareus <robin@gareus.org>
  * add input signal level to data-structure
  * add interfaces to set encoder volume and filter
  * adjust decoder biphase tracking (allow rounding down to 1 sample)
  * use ltc_off_t for all (long long int)
  2012-10-21 (v0.7.0) Robin Gareus <robin@gareus.org>
  * add support for reverse encoding
  * add interface to decrement encoder timecode
  * rename interface to increment encoder timecode
  2012-10-21 (v0.6.2) Robin Gareus <robin@gareus.org>
  * fix ltc_encoder_encode_byte() return value
  2012-10-21 (v0.6.1) Robin Gareus <robin@gareus.org>
  * add realtime safe interface to change fps
  * fix: set parity also when decrementing frame numbers
  * update documentation - fix typos, clarificaions
  2012-10-13 (v0.6.0) Robin Gareus <robin@gareus.org>
  * set parity bit on encoding - keep polarity of the waveform constant
  2012-10-09 (v0.5.3) Robin Gareus <robin@gareus.org>
  * add interface to decrement timecode
  2012-10-04 (v0.5.2) Robin Gareus <robin@gareus.org>
  * expose detailed timing info in extended LTC Frame
  allow to re-construct the phase of the signal
  2012-08-23 (v0.5.1) Robin Gareus <robin@gareus.org>
  * add ability to read reverse LTC
  * use 64bit values (long long) for position offset
  * minor fixes, typos, doc
  2012-08-15 (v0.5.0) Robin Gareus <robin@gareus.org>
  * refactored libltcsmpte.sf.net into libltc
